Plot coverage probabilities for the fixed and random effects.
See also
Other Figure Functions:
FigBias(),
FigPower(),
FigRMSE()
Examples
if (FALSE) { # \dontrun{
data(results, package = "manMetaVAR")
FigCoverage(results)
} # }
Plot coverage probabilities for the fixed and random effects.
Other Figure Functions:
FigBias(),
FigPower(),
FigRMSE()
if (FALSE) { # \dontrun{
data(results, package = "manMetaVAR")
FigCoverage(results)
} # }