Plot statistical power probabilities for the fixed and random effects.
See also
Other Figure Functions:
FigBias(),
FigCoverage(),
FigRMSE()
Examples
if (FALSE) { # \dontrun{
data(results, package = "manMetaVAR")
FigPower(results)
} # }
Plot statistical power probabilities for the fixed and random effects.
Other Figure Functions:
FigBias(),
FigCoverage(),
FigRMSE()
if (FALSE) { # \dontrun{
data(results, package = "manMetaVAR")
FigPower(results)
} # }