Plot relative bias for the fixed and random effects.
Arguments
- results
resultsdata frame.- bias
Logical. If
bias = TRUE, plot absolute bias. Ifbias = FALSE, plot relative bias. Note that when parameter value is equal to zero, absolute bias is used instead of relative bias.- method
Character vector. Methods to include in the plot.
- parameters
Character string. Parameters to plot. Valid values include
"fixed","random", and"both".- ylim
Numeric vector of length 2. Lower and upper limits for the y-axis.
- x_lab_size
Numeric. x-axis label size.
See also
Other Figure Functions:
FigCoverage(),
FigPower(),
FigRMSE()
Examples
if (FALSE) { # \dontrun{
data(results, package = "manMetaVAR")
FigBias(results)
} # }