Methods for Objects of Class manmetavar.dtvar
Source: R/manMetaVAR-methods-dt-var.R
manmetavar-dtvar-methods.RdThis page documents the available methods for objects of class
manmetavar.dtvar.
Usage
# S3 method for class 'manmetavar.dtvar'
coef(
object,
mu = TRUE,
alpha = TRUE,
beta = TRUE,
nu = TRUE,
psi = TRUE,
theta = TRUE,
ncores = NULL,
...
)
# S3 method for class 'manmetavar.dtvar'
vcov(
object,
mu = TRUE,
alpha = TRUE,
beta = TRUE,
nu = TRUE,
psi = TRUE,
theta = TRUE,
robust = FALSE,
ncores = NULL,
...
)
# S3 method for class 'manmetavar.dtvar'
print(
x,
means = FALSE,
mu = TRUE,
alpha = TRUE,
beta = TRUE,
nu = TRUE,
psi = TRUE,
theta = TRUE,
digits = 4,
ncores = NULL,
...
)
# S3 method for class 'manmetavar.dtvar'
summary(
object,
means = FALSE,
mu = TRUE,
alpha = TRUE,
beta = TRUE,
nu = TRUE,
psi = TRUE,
theta = TRUE,
digits = 4,
ncores = NULL,
...
)Arguments
- object
Object of class
manmetavar.dtvar.- mu
Logical. If
mu = TRUE, include estimates of themuvector, if available. Ifmu = FALSE, exclude estimates of themuvector.- alpha
Logical. If
alpha = TRUE, include estimates of thealphavector, if available. Ifalpha = FALSE, exclude estimates of thealphavector.- beta
Logical. If
beta = TRUE, include estimates of thebetamatrix, if available. Ifbeta = FALSE, exclude estimates of thebetamatrix.- nu
Logical. If
nu = TRUE, include estimates of thenuvector, if available. Ifnu = FALSE, exclude estimates of thenuvector.- psi
Logical. If
psi = TRUE, include estimates of thepsimatrix, if available. Ifpsi = FALSE, exclude estimates of thepsimatrix.- theta
Logical. If
theta = TRUE, include estimates of thethetamatrix, if available. Iftheta = FALSE, exclude estimates of thethetamatrix.- ncores
Positive integer. Number of cores to use.
- ...
additional arguments.
- robust
Logical. If
TRUE, use robust (sandwich) sampling variance-covariance matrix. IfFALSE, use normal theory sampling variance-covariance matrix.- x
Object of class
manmetavar.dtvar.- means
Logical. If
means = TRUE, return means. Otherwise, the function returns raw estimates.- digits
Integer indicating the number of decimal places to display.